#! /usr/bin/env python3
from vaspwiki.version import __version__
from vaspwiki.version import __author__
from vaspwiki.version import __maintainer__
from vaspwiki.version import __release_data__
from vaspwiki.version import __license__

__all__ = ['vaspwiki']

