#! /usr/bin/env python3

__version__ = '1.1.1'
__author__ = 'Yue-Wen FANG'
__maintainer__ = "Yue-Wen FANG"
__email__ = 'fyuewen@gmail.com'
__license__ = 'MIT License'
__release_data__= 'Dec. 27, 2018'